function [driveNames, dummyStateNames,functionNames, globalDataNames ] = getDriveTemplateNames()
%GETDRIVETEMPLATENAMES Given the modelH, get the driveNames and simulink
%function names ( used for representing the motion api calls in generated ST)
%
% Outputs :
%         driveNames :  Names of all the drives present. These model the
%         drive behaviour and are atomic subcharts linked from a seperate
%         drive model. each drive represents an axis and so we may have
%         multiple drives. Since we want to generate the ST for only the
%         controller we get the names  of the drive models in order to
%         delete them before ST generation. However, these are required for
%         simulation
%        
%         functionNames : names of the motion api function calls. These
%         motion api calls are needed for simulation and also need to
%         appear in the ST code. However, 
%               a) these should appear as function calls just as
%               represented in the controller. They should not get inlined
%               b) the definition should not get generated. So we add these 
%               to the plc options symbols that are to not to be generated.
%
%         globalDataNames  :  names of the motionAPI global data structures,
%         which behind hte scenes are used to updated the status of the api
%         instruction calls both in the controller and the drive. These are
%         data store memories in the stateflow chart. The type
%         definition for these should not be generated in the ST as these
%         will be provided by RSLogix. So we add these to the plc options
%         symbols that are to not to be generated.

    driveNames = {'Drive1', 'Drive2', 'DriveModel'};
    dummyStateNames = {'DummyLogger'};
    functionNames = {'MSF', 'MSO', 'MAM'};
    globalDataNames = {'AXIS_SERVO_DRIVE', 'MOTION_INSTRUCTION', 'MAMDATA'};

end